@@ -1,10 +1,12 @@
 import json
 import sys
 from datetime import datetime
-from typing import Optional
-
+from typing import Optional, Tuple
+from pydantic import BaseModel  # type: ignore
+import yaml
 import click
 import requests
+import os
 
 from treebeard.helper import get_treebeard_env
 from treebeard.version import get_version
@@ -53,3 +55,19 @@ def get_service_status_message(service_status_url: str) -> Optional[str]:
     if "message" in data:
         return data["message"]
     return None
+
+
+class TreebeardConfig(BaseModel):  # type: ignore
+    notebook: str = "main.ipynb"
+    ignore: Tuple[str, ...] = ()
+    secret: Tuple[str, ...] = ()
+
+
+def get_treebeard_config() -> Optional[TreebeardConfig]:
+    config = "treebeard.yaml"
+    if not os.path.exists(config):
+        return None
+
+    with open(config) as f:
+        conf = yaml.load(f, Loader=yaml.FullLoader)
+        return TreebeardConfig(**conf)
