@@ -8,6 +8,11 @@ from pathlib import Path
 import click
 import requests
 
+if os.getenv("TREEBEARD_ENVIRONMENT") is None:
+    env = "production"
+else:
+    env = os.getenv("TREEBEARD_ENVIRONMENT")
+
 
 def get_config_path():
     home = str(Path.home())
